@@ -24,8 +24,8 @@
 
 
 Analyzer::Base::Base(QWidget *parent, uint scopeSize)
-        : QWidget(parent)
-        , m_fht(new FHT(scopeSize))
+    : QWidget(parent)
+    , m_fht(new FHT(scopeSize))
 {}
 
 void Analyzer::Base::transform(QVector<float> &scope ) //virtual
@@ -50,21 +50,20 @@ void Analyzer::Base::transform(QVector<float> &scope ) //virtual
 void Analyzer::Base::drawFrame(const QMap<Phonon::AudioDataOutput::Channel, QVector<qint16> > &thescope)
 {
     if (thescope.isEmpty())
-      return;
+        return;
 
-    static QVector<float> scope( 512 );
+    QVector<float> scope( 512 );
     int i = 0;
 
-    for( uint x = 0; (int)x < m_fht->size(); ++x )
-    {
-      if (thescope.size() == 1) { // Mono
-        scope[x] = double(thescope[Phonon::AudioDataOutput::LeftChannel][x]);
-      } else { // Anything > Mono is treated as Stereo
-        scope[x] = double(thescope[Phonon::AudioDataOutput::LeftChannel][x]
-                          + thescope[Phonon::AudioDataOutput::RightChannel][x])
-                          / (2*(1<<15)); // Average between the channels
-      }
-       i += 2;
+    for( uint x = 0; (int)x < m_fht->size(); ++x ) {
+        if (thescope.size() == 1) { // Mono
+            scope[x] = double(thescope[Phonon::AudioDataOutput::LeftChannel][x]);
+        } else { // Anything > Mono is treated as Stereo
+            scope[x] = double(thescope[Phonon::AudioDataOutput::LeftChannel][x]
+                       + thescope[Phonon::AudioDataOutput::RightChannel][x])
+                    / (2*(1<<15)); // Average between the channels
+        }
+        i += 2;
     }
 
     transform(scope);
@@ -114,8 +113,8 @@ void Analyzer::Base::paused() //virtual
 
 void Analyzer::Base::demo() //virtual
 {
-        static int t = 201; //FIXME make static to namespace perhaps
-//    qDebug() << Q_FUNC_INFO << t;
+    static int t = 201; //FIXME make static to namespace perhaps
+    //    qDebug() << Q_FUNC_INFO << t;
 
     if( t > 300 ) t = 1; //0 = wasted calculations
     if( t < 201 )
@@ -136,7 +135,7 @@ void Analyzer::Base::demo() //virtual
 
 
 Analyzer::Base2D::Base2D(QWidget *parent, uint scopeSize)
-   : Base(parent, scopeSize)
+    : Base(parent, scopeSize)
 {
     QTimer::singleShot(0, this, SLOT(init())); // needs to know the size
     timer.setInterval(34);
